.. _user-guide:

User guide
##########

This user guide covers different topics related to BoARIO, as well as some
hands-on tutorials on how to use the library to run simulations.

.. toctree::
   :maxdepth: 1

   boario-terminology
   boario-tutorials
   boario-math
